text stringlengths 12 1.05M | repo_name stringlengths 5 86 | path stringlengths 4 191 | language stringclasses 1
value | license stringclasses 15
values | size int32 12 1.05M | keyword listlengths 1 23 | text_hash stringlengths 64 64 |
|---|---|---|---|---|---|---|---|
from plotly.basedatatypes import BaseTraceType as _BaseTraceType
import copy as _copy
class Densitymapbox(_BaseTraceType):
# class properties
# --------------------
_parent_path_str = ""
_path_str = "densitymapbox"
_valid_props = {
"autocolorscale",
"below",
"coloraxis",
... | plotly/plotly.py | packages/python/plotly/plotly/graph_objs/_densitymapbox.py | Python | mit | 80,557 | [
"Gaussian"
] | d4429adda8160c5314dae707e2f20c29027bf3123962f9db07e1bdb52f04d64e |
# -*- coding: utf-8 -*-
"""
Authors: Tim Hessels
UNESCO-IHE 2017
Contact: t.hessels@unesco-ihe.org
Repository: https://github.com/wateraccounting/wa
Module: Function/Four
"""
def Fraction_Based(nc_outname, Startdate, Enddate):
"""
This functions divides an array into groundwater and surface water base... | wateraccounting/wa | Functions/Four/SplitGW_SW_Supply.py | Python | apache-2.0 | 2,179 | [
"NetCDF"
] | 27577c6d3e8bb2c3b6a36760035db719984925dc0d476ea75143094c53601bcb |
#!/usr/bin/python
#
# @author: Gaurav Rastogi (grastogi@avinetworks.com)
# Eric Anderson (eanderson@avinetworks.com)
# module_check: supported
# Avi Version: 17.1.1
#
# Copyright: (c) 2017 Gaurav Rastogi, <grastogi@avinetworks.com>
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses... | hryamzik/ansible | lib/ansible/modules/network/avi/avi_analyticsprofile.py | Python | gpl-3.0 | 29,130 | [
"VisIt"
] | e0b29afab8d95aa1ea0b697470837b43a1e162713969159e6c2dcfacdf147873 |
#!/usr/bin/env python
import matplotlib as mpl
import desdb
import numpy as np
import esutil
import pyfits
import sys
import argparse
import healpy as hp
import os
import functions2
import slr_zeropoint_shiftmap as slr
import numpy.lib.recfunctions as rf
import matplotlib.pyplot as plt
def NoSimFields(band='i'):
... | emhuff/regularizedInversion | des_color_inference.py | Python | mit | 15,630 | [
"Galaxy"
] | 0c0a283724ef9a1553bf3a9918631d0337199c6a392754b6276a976d429ec676 |
#! /usr/bin/env python
import owyl
from owyl import blackboard
import rospy
class Tree():
def __init__(self):
self.blackboard = blackboard.Blackboard("breath tree")
self.tree = self.build_tree()
while True:
self.tree.next()
def build_tree(self):
eva_breath_tree = \... | linas/eva_behavior | src/eva_breath.py | Python | lgpl-2.1 | 744 | [
"VisIt"
] | 7ad65f4d25cf0bdb46bcfa1d5ce458214a1f519734f37e6f977aa278774eec76 |
import numpy as np
import os
try:
import netCDF4 as netCDF
except:
import netCDF3 as netCDF
import matplotlib.pyplot as plt
import time
import datetime as dt
from matplotlib.dates import date2num, num2date
import pyroms
import pyroms_toolbox
import _remapping
class nctime(object):
pass
def remap_bdry_uv(src_... | kshedstrom/pyroms | examples/CCS1_SODA3.3.1/Boundary/remap_bdry_uv.py | Python | bsd-3-clause | 14,025 | [
"NetCDF"
] | 0f6ee67988e6e0856245bcf19e9b66d79d053dc6714d1dd902682ea4a9c92c97 |
# IPython log file
import numpy as np
from IPython import get_ipython
from numba import cuda
cuda.detect()
n = int(1e6)
a = np.random.rand(n)
b = np.random.rand(n)
out = np.zeros_like(a)
@cuda.jit
def add_gpu(a, b, out):
i = cuda.threadIdx.x
if i < a.size:
out[i] = a[i] + b[i]
get_ipython().ma... | jni/useful-histories | numba-cuda.py | Python | bsd-3-clause | 3,324 | [
"Gaussian"
] | a2e9a4c893ffa128e740a93a309340ed9fac847b57705746984dd15311c13c12 |
"""
Calculate the average protein lengths from the blast output files.
"""
import os
import sys
import argparse
from roblib import bcolors, median
def av_protein_lengths(sample, blastfile, fractionout, summaryout, searchtype):
"""
Calculate the average length of the best hit of all the proteins
"""
q ... | linsalrob/EdwardsLab | phage/phage_quality_assessment_scripts/av_protein_lengths.py | Python | mit | 1,633 | [
"BLAST"
] | 2a267e62a29d052131a40581c0fc73d4b3fc6dc333f68be055eae9cd8c69286a |
# $Id$
#
# Copyright (C) 2003-2006 greg Landrum and Rational Discovery LLC
#
# @@ All Rights Reserved @@
# This file is part of the RDKit.
# The contents are covered by the terms of the BSD license
# which is included in the file license.txt, found at the root
# of the RDKit source tree.
#
"""
unit testing code... | rvianello/rdkit | rdkit/Chem/Suppliers/UnitTestSmilesMolSupplier.py | Python | bsd-3-clause | 3,573 | [
"RDKit"
] | 714ef9c024f7e095950df42e12ca7ea7fc411182af2465d6fd65d94380b6bfad |
# ----------------------------------------------------------------------
# Numenta Platform for Intelligent Computing (NuPIC)
# Copyright (C) 2013, Numenta, Inc. Unless you have an agreement
# with Numenta, Inc., for a separate license for this software code, the
# following terms and conditions apply:
#
# This progra... | neuroidss/nupic.vision | nupicvision/regions/PictureSensorExplorers/rotate_block.py | Python | gpl-3.0 | 3,166 | [
"VisIt"
] | f7c310f4a49324b981de43dc8ef27ab719fbbdc144c63ea7b0011df0891a126a |
# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft = python sts = 4 ts = 4 sw = 4 et:
"""Afni preprocessing interfaces
Change directory to provide relative paths for doctests
>>> import os
>>> filepath = os.path.dirname( os.path.realpath( __file__ ) )
>>> datadir = o... | FCP-INDI/nipype | nipype/interfaces/afni/preprocess.py | Python | bsd-3-clause | 112,150 | [
"Gaussian"
] | 0e7c9d556b0638c94347a647711a1eadeb68e3ad4f2afd0f5670eb3b2fefc689 |
#!/usr/bin/env python
#
# Copyright (C) 2009 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable ... | boxed/CMi | web_frontend/gdata/sample_util.py | Python | mit | 10,714 | [
"VisIt"
] | 24751ae2fb6827b35b2fcdbbfc22b1274c142d7b6261fc42b74101d7515eba9d |
# -*- coding: utf-8 -*-
#########################################################################
#
# Copyright (C) 2016 OSGeo
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 ... | simod/geonode | geonode/geoserver/tests.py | Python | gpl-3.0 | 40,693 | [
"VisIt"
] | 0f21fec3d1686743f6b7a95b61228ab89c5616c3101248ce8edc8fe136d16adc |
import unittest
__author__ = 'Alexander Weigl <Alexander.Weigl@student.kit.edu>'
__date__ = "2015-02-19"
__version__ = "0.1"
import clictk, os.path
ROOT = os.path.dirname(os.path.abspath(__file__))
from xml.etree import ElementTree
from xml.dom import minidom
def prettify(elem):
"""Return a pretty-printed XML... | CognitionGuidedSurgery/pyclictk | test/test_nifty.py | Python | lgpl-3.0 | 21,359 | [
"Gaussian"
] | f269d26bad0cf963a38ee3343ecbaea6c3a25d54d9522948fdebf13f87294d6f |
# Copyright (c) 2015,Vienna University of Technology,
# Department of Geodesy and Geoinformation
# All rights reserved.
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# * Redistributions of source code must retain the... | TUW-GEO/SMDC-performance | smdc_perftests/datasets/EQUI_7.py | Python | bsd-3-clause | 3,619 | [
"NetCDF"
] | f09eeb1b60d91589c46e8ef6eac33005156713144890b0453628872e2a301870 |
"""M-probability estimate"""
import numpy as np
import pandas as pd
from sklearn.base import BaseEstimator
from category_encoders.ordinal import OrdinalEncoder
import category_encoders.utils as util
from sklearn.utils.random import check_random_state
__author__ = 'Jan Motl'
class MEstimateEncoder(BaseEstimator, util... | scikit-learn-contrib/categorical-encoding | category_encoders/m_estimate.py | Python | bsd-3-clause | 11,352 | [
"Gaussian"
] | d442dcc7db29e39bc1386b62b70a8b3360a5a1ce9568003cb5e3f8e4c1b03705 |
#!/usr/bin/env python
## \file plot.py
# \brief python package for plotting
# \author T. Lukaczyk, F. Palacios
# \version 5.0.0 "Raven"
#
# SU2 Lead Developers: Dr. Francisco Palacios (Francisco.D.Palacios@boeing.com).
# Dr. Thomas D. Economon (economon@stanford.edu).
#
# SU2 Developers: Prof.... | opfeifle/SU2 | SU2_PY/SU2/util/plot.py | Python | lgpl-2.1 | 3,559 | [
"ParaView"
] | da7b81b0e8c16a6120cda24e7f5faf27d85ccf3d90d66155afca37457e6b7348 |
##############################################################################
# Copyright (c) 2013-2017, Lawrence Livermore National Security, LLC.
# Produced at the Lawrence Livermore National Laboratory.
#
# This file is part of Spack.
# Created by Todd Gamblin, tgamblin@llnl.gov, All rights reserved.
# LLNL-CODE-64... | lgarren/spack | lib/spack/spack/spec.py | Python | lgpl-2.1 | 139,642 | [
"VisIt"
] | f9156a59eb9717e48b64759c05610a4b56c2fceff322ba1d7b07f5dc6414de5e |
# - Coding UTF8 -
#
# Networked Decision Making
# Development Sites (source code):
# http://code.google.com/p/global-decision-making-system/
# http://github.com/NewGlobalStrategy/NetDecisionMaking
#
# Demo Sites (Google App Engine)
# http://netdecisionmaking.appspot.com
# http://globaldecisionmaking.appspot.co... | NewGlobalStrategy/NetDecisionMaking | controllers/search.py | Python | mit | 4,809 | [
"VisIt"
] | 99c0234379141afa9ad6900b684861ce84097acb17d29d1bba7fd16ac47a127b |
import glob
try: paraview.simple
except: from paraview.simple import *
paraview.simple._DisableFirstRenderCameraReset()
# TODO:
# 1. Set min/max value for every frame in AnimationScene
# See http://www.paraview.org/pipermail/paraview/2011-September/022682.html
#
LoadPlugin('/Users/schmitt/paraview/paraview... | ghost-kit/archive | scripts/LFM_mhd_ParaView.py | Python | bsd-3-clause | 16,165 | [
"ParaView"
] | 7b9f71d2334e688ccfb3135b79133b399381686fe8aedcf60e69b681615f0338 |
# Copyright (C) 2012,2013
# Max Planck Institute for Polymer Research
# Copyright (C) 2008,2009,2010,2011
# Max-Planck-Institute for Polymer Research & Fraunhofer SCAI
#
# This file is part of ESPResSo++.
#
# ESPResSo++ is free software: you can redistribute it and/or modify
# it under the terms of the G... | MrTheodor/espressopp | src/__init__.py | Python | gpl-3.0 | 2,605 | [
"ESPResSo"
] | 46bdd8e6bd54e2ca7b28f9f957f2fac735f9c7a4e379f21570244d8d32e46d68 |
# Audio Tools, a module and set of tools for manipulating audio data
# Copyright (C) 2007-2016 Brian Langenberger
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the Licens... | tuffy/python-audio-tools | audiotools/id3v1.py | Python | gpl-2.0 | 11,355 | [
"Brian"
] | 45c93c586873470dbc111b1c30ce8aec4d08407d74ceaf219482bf46be1ec536 |
# -*- coding: utf-8 -*-
"""
End-to-end tests for survey of biz feature
"""
import codecs
import csv
import os
import shutil
from bok_choy.web_app_test import WebAppTest
from django.utils.crypto import get_random_string
from nose.plugins.attrib import attr
from common.test.acceptance.pages.biz.ga_contract import BizCo... | nttks/edx-platform | common/test/acceptance/tests/biz/test_ga_survey.py | Python | agpl-3.0 | 17,522 | [
"VisIt"
] | 2abe184210a74e8a8973c825ca491977487225944eb1ab6d9f95b04addd5f555 |
#==============================================================================
#
# Program: ParaView
# Module: annotation.py
#
# Copyright (c) Kitware, Inc.
# All rights reserved.
# See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.
#
# This software is distributed WITHOUT ANY ... | HopeFOAM/HopeFOAM | ThirdParty-0.1/ParaView-5.0.1/Wrapping/Python/paraview/annotation.py | Python | gpl-3.0 | 6,555 | [
"ParaView",
"VTK"
] | 56dd0cb05fbd68ddc785c76df2fc656a6d854bbfb1708592ae554916bda6c4de |
from ase import Atoms
from ase.units import Bohr
from gpaw import GPAW
from gpaw.test import equal
a = 7.5 * Bohr
n = 16
atoms = Atoms('He', [(0.0, 0.0, 0.0)], cell=(a, a, a), pbc=True)
calc = GPAW(gpts=(n, n, n), nbands=1, xc='PBE')
atoms.set_calculator(calc)
e1 = atoms.get_potential_energy()
niter1 = calc.get_number... | ajylee/gpaw-rtxs | gpaw/test/nonselfconsistent.py | Python | gpl-3.0 | 1,069 | [
"ASE",
"GPAW"
] | 5a7cbf284ef810fd322658d54b2e3dafc5f45cfe9166dd6e7a3dbf8e5da479a7 |
import sys
from ase.build import molecule, fcc111, add_adsorbate
from ase.optimize import QuasiNewton
from ase.constraints import FixAtoms
from ase.calculators.emt import EMT
from ase.vibrations import Vibrations
sys.path.append("../..")
from __init__ import AnharmonicModes
slab = fcc111('Au', size=(2, 2, 2), vacuu... | keldLundgaard/ase-anharmonics | examples/translate_on_surface/translate_H_on_Au_z-relax__EMT.py | Python | lgpl-2.1 | 1,454 | [
"ASE"
] | ccd769749322371375d15a3df513635718dd060da9e5ccd311d63f6c007844ea |
# Copyright 2014, Brian Coca <bcoca@ansible.com>
# Copyright 2017, Ken Celenza <ken@networktocode.com>
# Copyright 2017, Jason Edelman <jason@networktocode.com>
# Copyright 2017, Ansible Project
#
# This file is part of Ansible
#
# Ansible is free software: you can redistribute it and/or modify
# it under the terms of ... | srvg/ansible | lib/ansible/plugins/filter/mathstuff.py | Python | gpl-3.0 | 9,450 | [
"Brian"
] | 543de4da987f6ec211ad2dd4f19557e26b59c7041a8305f75900c67d054cd412 |
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at https://mozilla.org/MPL/2.0/.
from collections import namedtuple
from itertools import groupby
from numbers import Integral
import numpy as np
from s... | zerothi/sisl | sisl/geom/surfaces.py | Python | mpl-2.0 | 25,395 | [
"CRYSTAL"
] | b3cf63e64f569c916083f59b051e8d0fb746140c108eb02eb0cee6e7d16a0529 |
######################################################################
##
## Copyright 2010-2011 Ondrej Certik <ondrej@certik.cz>
## Copyright 2010-2011 Mateusz Paprocki <mattpap@gmail.com>
## Copyright 2011 Christian Iversen <ci@sikkerhed.org>
##
## Permission is hereby granted, free of charge, to any person
## obtain... | buchuki/pyjaco | pyjaco/compiler/javascript.py | Python | mit | 14,252 | [
"VisIt"
] | 19da70e6327407482af986fc1d58c2a494397d302c3e7c2723d60167b7122064 |
# Copyright (c) 2012 OpenStack Foundation
# All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless ... | isyippee/nova | nova/tests/unit/compute/test_resource_tracker.py | Python | apache-2.0 | 55,312 | [
"exciting"
] | 2ead65a9f3beb73d887f997f8baa70407a284e12603175633ae04f0ba0ce1593 |
"""
PRMS Vegetation Change Modeling API
Date: Feb 25 2016
"""
import datetime
import json
import math
import netCDF4
import os
from flask import jsonify, request, Response
from flask import current_app as app
from urllib import urlretrieve
from uuid import uuid4
from . import api
from ..models import Scenario, Hydro... | VirtualWatershed/prms-vegetation-scenarios | app/api/views.py | Python | bsd-3-clause | 7,327 | [
"NetCDF"
] | f11c209226263e1890773ed93297b1fddd2e7622b1ce8a49e2d28748c1ae1fc3 |
from __future__ import print_function
import matplotlib
import numpy as np
import copy
import re
import warnings
from astropy import log
from astropy import units as u
from astropy.extern.six.moves import xrange
from astropy.extern.six import string_types
from ..config import mycfg
from ..config import ConfigDescript... | allisony/pyspeckit | pyspeckit/spectrum/fitters.py | Python | mit | 91,957 | [
"Gaussian"
] | 260d7ae411b91a15e9e83f6cc8254648d3292bf83b3b730d29fe70728bbfb92c |
# -*- coding: utf-8 -*-
#########################################################################
## This program is part of 'MOOSE', the
## Messaging Object Oriented Simulation Environment.
## Copyright (C) 2013 Upinder S. Bhalla. and NCBS
## It is made available under the terms of the
## GNU Lesser General ... | dilawar/moose-core | tests/core/test_function_change_expr.py | Python | gpl-3.0 | 3,325 | [
"MOOSE"
] | 30da864222340dbefcd5ff5a98c97b1e7202053a4037920f7374b25a10c8f4ee |
########################################################################
# File : ComputingElementFactory.py
# Author : Stuart Paterson
########################################################################
""" The Computing Element Factory has one method that instantiates a given Computing Element
from the ... | andresailer/DIRAC | Resources/Computing/ComputingElementFactory.py | Python | gpl-3.0 | 2,678 | [
"DIRAC"
] | 02ce9360bc47d5085c9a2278e062f76ae928bf83a78986f844a0669a62ce5f41 |
""" Hiding calls to PYPIT used in arclines
Avoid double dependency if possible
"""
from __future__ import absolute_import, division, print_function
import numpy as np
import pdb
from arclines import utils as al_utils
def find_peaks(censpec):
"""
Parameters
----------
censpec
siglev
bpfit : i... | PYPIT/arclines | arclines/pypit_utils.py | Python | bsd-3-clause | 2,208 | [
"Gaussian"
] | 52426af0c26e8ccd74d73a416acdbdd7ebc35e0407cb0f48159541fbe68cfc54 |
# coding: utf-8
# Copyright 2016 Thomas Schatz, Xuan-Nga Cao, Mathieu Bernard
#
# This file is part of abkhazia: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later v... | bootphon/abkhazia | abkhazia/corpus/prepare/buckeye_preparator.py | Python | gpl-3.0 | 13,370 | [
"COLUMBUS"
] | 80a7238b4ad94e6748a738b409ed85281f8383bf38202e5db22ab5edd4137198 |
# -*- coding: utf-8 -*-
"""Mocks for PyBEL testing."""
import itertools as itt
import os
from unittest import mock
from .constants import bel_dir_path, belanno_dir_path, belns_dir_path
from .utils import get_uri_name
__all__ = [
"MockResponse",
"MockSession",
"mock_bel_resources",
]
_responses = [
... | pybel/pybel | src/pybel/testing/mocks.py | Python | mit | 2,504 | [
"Pybel"
] | dbbc39a21bc6ba164f289e361d13d05609d03e136da0e25238cbd178764722b7 |
# coding: utf-8
# # Functional connectivity
# Read data path and define result path, Create a list of atlas names, Extract time series and compute network connectivities per particiapnt.
#
# All done on YNiC server.
# pandas version >= 0.17.0
# # Matching behavioural and FC data
import csv
import glob
import os
i... | htwangtw/Patterns-of-Thought | notebooks/1.3-DataSelection.py | Python | mit | 5,632 | [
"VisIt"
] | a9150413bdb43241a8f12aa27f2c4514737dd1c19e3771a1427a303eed268b9d |
# -*- coding: utf-8 -*-
"""
Created on Tue Nov 15 12:05:40 2016
@author: sjjoo
"""
import sys
import mne
import matplotlib.pyplot as plt
from mne.utils import run_subprocess, logger
import os
from os import path as op
import copy
import shutil
import numpy as np
from numpy.random import randn
from scipy import stats ... | yeatmanlab/BrainTools | projects/NLR_MEG/forward_session1.py | Python | bsd-3-clause | 7,954 | [
"Mayavi"
] | d015c024aeebb37436cf01de5a32f99ea662a6a9fd9baab30710401b2c1724db |
#
# co_co_type_of_buffer_unique.py
#
# This file is part of NEST.
#
# Copyright (C) 2004 The NEST Initiative
#
# NEST is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at y... | kperun/nestml | pynestml/cocos/co_co_type_of_buffer_unique.py | Python | gpl-2.0 | 2,956 | [
"NEURON"
] | d452820abc2d218dc41f21892590c20b5830e6f5432c2c891098f579eb07e13a |
import iotkit
import sys
import time
import math
# Authentication/Account info
username = "bbaltz@yahoo.com"
password = "Passw0rd"
hostname = "dashboard.us.enableiot.com"
account_name = "Brian Baltz"
# Device/component info
device_id = "foobie3"
device_name = device_id + "-Device"
component_name = "response"
# make ... | bbaltz505/iotkit-libpy | getdata2.py | Python | bsd-3-clause | 1,792 | [
"Brian"
] | 6b8fe06219168881ad7b2ec2668669b12b71bad431601eb1e29608c792af5784 |
# (C) 2015 - Jaguar Land Rover.
#
# Mozilla Public License 2.0
#
# Python dbus service that faces SOTA interface
# of Software Loading manager.
import gtk
import dbus
import dbus.service
from dbus.mainloop.glib import DBusGMainLoop
import getopt
import sys
import time
import swm
import traceback
# Default command l... | magnusfeuer/genivi_software_management | sota_client/sota_client.py | Python | mpl-2.0 | 5,746 | [
"Jaguar"
] | f8c3b7f7cf111f56ee56e94fe55ade7dbf4b25e454b409fde94e0b166604b150 |
###########################################################################
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# https://www.apache.org/l... | google/starthinker | dags/email_cm_to_bigquery_dag.py | Python | apache-2.0 | 5,356 | [
"VisIt"
] | a6956c17113ac2a294c881a0f2ca1785dbfcec284aa0d2695448546dfb210471 |
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# HORTON: Helpful Open-source Research TOol for N-fermion systems.
# Copyright (C) 2011-2017 The HORTON Development Team
#
# This file is part of HORTON.
#
# HORTON is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public Licens... | tovrstra/horton | doc/update_functionals.py | Python | gpl-3.0 | 4,252 | [
"Octopus"
] | 78deaecf49635893e915dae8147b64f76e785265945c450dbc3af0f3e3078718 |
import os
import pymc
import pymbar
import dipoles
import numpy as np
import pandas as pd
import simtk.openmm.app as app
import simtk.openmm as mm
import simtk.unit as u
import mdtraj as md
traj = md.load("./monopole.pdb")
out_dir = os.path.join(os.getenv("HOME"), "dat", "monopoles-symmetric")
q0 = pymc.Uniform("q0"... | kyleabeauchamp/DBayes | dbayes/simulate/simulate_monopoles.py | Python | gpl-2.0 | 1,243 | [
"MDTraj",
"OpenMM"
] | a019618e0aa94d718e89cc30c1aa8ed48bba8ba8c1b5e85ebbae866db3323968 |
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import sys
print (sys.version)
import time
import numpy as np
my_dir = os.path.abspath(os.path.dirname(__file__))
# --------------------------------------------------------- #
# functions #
# -----------------... | dmerz75/emolsion | test/plot_emol_contacts.py | Python | mit | 4,042 | [
"NAMD"
] | e3208ef190798a66985c52ce6f68fe5bceb2463e6f27872a21bb122397fd4ed3 |
# coding: utf-8
from __future__ import unicode_literals
import re
from .common import InfoExtractor
from ..utils import (
determine_ext,
int_or_none,
)
class GediDigitalIE(InfoExtractor):
_VALID_URL = r'''(?x)https?://video\.
(?:
(?:
(?:espresso\.)?repubblica
... | rg3/youtube-dl | youtube_dl/extractor/gedidigital.py | Python | unlicense | 7,100 | [
"ESPResSo"
] | 650445a194af9b6294b89e14c1a6588dfe6dca50e24dde84fea4baeae236192d |
'''
Contains a number of functions for generating virtual spectra from a protein
file, makes use of biopython for protein file parsing.
'''
import re
import itertools
import copy
import numpy as np
def coarsen(inArray, tol=0.5):
'''Bins ion mass predictions to integers within the closest 0.5.'''
return (np.ar... | DeclanCrew/LC_MS_MS_Search | PeptideDB.py | Python | gpl-3.0 | 5,522 | [
"Biopython",
"Dalton"
] | 0a41b4c2eaee25813372fe437e9b543de71a2847ba5f10a12d163c60f957260f |
#!/usr/bin/python
# Copyright (c) 2012 The Chromium Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
"""Convert SVN based DEPS into .DEPS.git for use with NewGit."""
import optparse
import os
import sys
import deps_utils
import git_to... | leighpauls/k2cro4 | tools/deps2git/deps2git.py | Python | bsd-3-clause | 7,006 | [
"VisIt"
] | 2281c5a03d3ac86b988b616d64afc842b4838b52ee3ddd5b0fe13938f64fd825 |
# -*- coding: utf-8 -*-
import abc
import datetime
import math
import random
import pygame.display
import pygame.image
import pygame.mask
import pygame.sprite
import engine
class BaseKiller(pygame.sprite.Sprite):
def touch_player(self, game):
game.status = game.LOSE
game.lives -= 1
class BaseF... | sblondon/jumpjump | src/ennemies.py | Python | gpl-3.0 | 6,070 | [
"Octopus"
] | fb33bee24326dfa7bea690cfa0a9993b9fbad2d248700bcffb4e673662ff41c8 |
#!/usr/bin/env python
# Common constants and methods for the Tn-seq pipeline
#
# Copyright (c) 2014 University of Washington
#------------------------------------------------------------------------------
# constants
#------------------------------------------------------------------------------
import os.path
import ... | elijweiss/Tn-seq | python/common.py | Python | mit | 3,799 | [
"BWA",
"Bowtie"
] | 2bcac3b9cedd7c238262dc79919ac0bd465f6b57cd809b9fc2946a2f0856b637 |
# -*- coding: utf-8 -*-
# vi:si:et:sw=4:sts=4:ts=4
##
## Copyright (C) 2005, 2006 Async Open Source <http://www.async.com.br>
## All rights reserved
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU Lesser General Public License as published by
## the Free Soft... | andrebellafronte/stoq | stoqlib/gui/wizards/personwizard.py | Python | gpl-2.0 | 8,302 | [
"VisIt"
] | baf4e28361709430a97cffc9e9e6ae381b6811419662b8910f1a619577123778 |
import numpy as np
import pandas as pd
import mdtraj as md
import nmrpystar
from sklearn.externals.joblib import Memory
from .simulation_parameters import CS_CACHE_PATH
CHEMICAL_SHIFT_MODEL = "shiftx2"
FIRST_FRAMES = None
amino_acids = ["R","H", "K", "D", "E", "S", "T", "N", "Q", "C", "G", "A", "I", "L", "M", "F", "... | choderalab/TrustButVerify | trustbutverify/analyzers.py | Python | gpl-2.0 | 8,341 | [
"MDTraj"
] | 755082b5f0bf1dbb2ea923bad39a3e3610776111e86a8f93ca85d8703d461528 |
"""KTEQ-FM GENIUS API FUNCTIONS.
This module contains all of the Genius API calls for the TeqBot project.
These api calls are all located centrally within this module for convenience.
All API calls will be built in this module, and corresponding wapper functions
will be created for each of these calls for TeqBot to us... | KTEQ-FM/kteq-teqbot | teqbot/genius.py | Python | unlicense | 13,688 | [
"VisIt"
] | 717e25ea34ef33c68339481f996a98c79567adc92853d0531ca9bd51afaaca94 |
import unittest, time, sys, random
sys.path.extend(['.','..','../..','py'])
import h2o2 as h2o
import h2o_cmd, h2o_import as h2i, h2o_jobs, h2o_glm
from h2o_test import verboseprint, dump_json, OutputObj
from tabulate import tabulate
class Basic(unittest.TestCase):
def tearDown(self):
h2o.check_sandbox_fo... | YzPaul3/h2o-3 | py2/testdir_single_jvm/test_GLM_basic_1.py | Python | apache-2.0 | 5,516 | [
"Gaussian"
] | 989b33cbaa47887383bf628e3029f8bcd54d4332ba0510e29992b5f05485ce7b |
from pymongo import MongoClient
import argparse
parser = argparse.ArgumentParser(description="Create a MongoDB collection of orthologues from an existing collection of internal BLAST hits.")
parser.add_argument("--host",
type=str,
default='localhost',
help... | peteashton/symbionts.org | tools/createOrthologuesCollection.py | Python | mit | 3,542 | [
"BLAST"
] | ffcfb072fb380ba2479e9aa40db41e08448532a9381027a030d5e360a2fad201 |
import copy
import time
import lb_loader
import numpy as np
import pandas as pd
import simtk.openmm as mm
from simtk import unit as u
from openmmtools import integrators, testsystems, hmc_integrators
pd.set_option('display.width', 1000)
n_steps = 1000
temperature = 300. * u.kelvin
collision_rate = 1.0 / u.picoseconds
... | kyleabeauchamp/HMCNotes | code/obsolete/benchmark_raw.py | Python | gpl-2.0 | 1,915 | [
"OpenMM"
] | 7041e1d2842796bbead8ff63c21e065b1eef516bb9c521645efb08958752af05 |
import collections
import heapq
import traceback
import weakref
import numpy
import six
import chainer
from chainer import _backprop_utils
from chainer.backends import cuda
from chainer import configuration
from chainer import function_hook
from chainer.graph_optimizations.static_graph_utilities \
import static_f... | rezoo/chainer | chainer/function_node.py | Python | mit | 38,426 | [
"VisIt"
] | a68f1192c989e2f586274c303bb0881417c6ce5aeadfbb2c79e8e9f3a6f4052c |
#!/usr/bin/env python
# Copyright 2014-2018 The PySCF Developers. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# U... | gkc1000/pyscf | pyscf/scf/test/test_jk.py | Python | apache-2.0 | 14,186 | [
"PySCF"
] | 486d3a7d9baeffff0f9222c209cbf6fd88ea567742a1eacccb47ed713cc14006 |
# class generated by DeVIDE::createDeVIDEModuleFromVTKObject
from module_kits.vtk_kit.mixins import SimpleVTKClassModuleBase
import vtk
class vtkMergeColumns(SimpleVTKClassModuleBase):
def __init__(self, module_manager):
SimpleVTKClassModuleBase.__init__(
self, module_manager,
vtk.v... | nagyistoce/devide | modules/vtk_basic/vtkMergeColumns.py | Python | bsd-3-clause | 479 | [
"VTK"
] | 5dcd9fe9e0ebe91318be68ca3c3d89d8fe11d55f67cda4bef07a900337cb9287 |
# -*- coding: utf-8 -*-
""" Tests for student account views. """
import re
from unittest import skipUnless
from urllib import urlencode
import json
import mock
import ddt
from django.conf import settings
from django.core.urlresolvers import reverse
from django.core import mail
from django.contrib import messages
from... | rismalrv/edx-platform | lms/djangoapps/student_account/test/test_views.py | Python | agpl-3.0 | 20,128 | [
"VisIt"
] | 0f6257ff0837fb4bcfb5e6ca2f42cb075f003cfbe12170ecd4233950f120c905 |
# -*- coding: utf-8 -*-
"""
functions.py - Miscellaneous functions with no other home
Copyright 2010 Luke Campagnola
Distributed under MIT/X11 license. See license.txt for more infomation.
"""
from __future__ import division
import warnings
import numpy as np
import decimal, re
import ctypes
import sys, struct
from ... | pbmanis/acq4 | acq4/pyqtgraph/functions.py | Python | mit | 94,557 | [
"Gaussian"
] | ab9e06c8727399c2c725f21e489f0368bf6ce3c356b74f57d05789cf944074fb |
# -*- coding: utf-8 -*-
import sys
sys.path[0:0] = [""]
import bson
import os
import pickle
import unittest
import uuid
from datetime import datetime
from bson import DBRef
from tests.fixtures import (PickleEmbedded, PickleTest, PickleSignalsTest,
PickleDyanmicEmbedded, PickleDynamicTest)
... | LethusTI/supportcenter | vendor/mongoengine/tests/document/instance.py | Python | gpl-3.0 | 77,386 | [
"exciting"
] | e927b2ca0972193bd6051fb814bc6abb49ec71ba0481282b7915af04b49d65e5 |
# -*- coding: utf-8 -*-
"""
General utilities
"""
import obspy.signal.filter
import numpy as np
from numpy.lib.stride_tricks import as_strided
from numpy.fft import rfft, irfft, rfftfreq
import os
import glob
import shutil
import pickle
import shapefile
import matplotlib.pyplot as plt
from matplotlib.patches import Po... | boland1992/SeisSuite | build/lib/seissuite/ant/psutils.py | Python | gpl-3.0 | 20,742 | [
"Gaussian"
] | aa2efc338f9fc1dd58ba165e8cc551ee5b18d1d1dfd75888b8756bae3c3fb926 |
# copyright 2003-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
#
# This file is part of astroid.
#
# astroid is free software: you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by the
#... | lukaszpiotr/pylama_with_gjslint | pylama/checkers/pylint/astroid/utils.py | Python | lgpl-3.0 | 8,246 | [
"VisIt"
] | f51f78e5d8a5fd8ede92ebb73be693bd016960ebd45e89644bbefc47fd137a5d |
from __future__ import (absolute_import, division, print_function)
import unittest
import os
from mantid.simpleapi import mtd, logger
import numpy as np
from mantid.simpleapi import Abins, DeleteWorkspace
from AbinsModules import AbinsParameters, AbinsTestHelpers
try:
from pathos.multiprocessing import Processing... | wdzhou/mantid | Framework/PythonInterface/test/python/plugins/algorithms/AbinsAdvancedParametersTest.py | Python | gpl-3.0 | 12,462 | [
"CRYSTAL"
] | b8d910b4a214947da2bd1a54d2e31ff53fe154b79ae90a1e30aa86ec32e7806f |
"""
cclib (http://cclib.sf.net) is (c) 2006, the cclib development team
and licensed under the LGPL (http://www.gnu.org/copyleft/lgpl.html).
"""
__revision__ = "$Revision: 737 $"
from PyQuante.Molecule import Molecule
def makepyquante(atomcoords, atomnos, charge=0, mult=1):
"""Create a PyQuante Molecule.
>>... | keceli/RMG-Java | source/cclib/bridge/cclib2pyquante.py | Python | mit | 828 | [
"cclib"
] | 0a27c2dfe6e19e67175d3d9128b1f486db97a5b9efdc9736cf56c073a90e68eb |
###############################################################################
# #
# Peekaboo Extended Email Attachment Behavior Observation Owl #
# #
... | scVENUS/PeekabooAV | peekaboo/config.py | Python | gpl-3.0 | 21,417 | [
"Amber"
] | d429aca4c9e80cd74ea6155f364fc5b29e78090fcd135627fe80eca615930812 |
# ----------------------------------------------------------------------------
# Copyright (c) 2013--, scikit-bio development team.
#
# Distributed under the terms of the Modified BSD License.
#
# The full license is in the file COPYING.txt, distributed with this software.
# --------------------------------------------... | corburn/scikit-bio | skbio/io/_iosources.py | Python | bsd-3-clause | 6,568 | [
"scikit-bio"
] | 82dc61f1ed6385494d3092c3e98ebeb3b511c416b0e55e9d91e6642a878bc291 |
# coding: utf-8
# Copyright (c) Pymatgen Development Team.
# Distributed under the terms of the MIT License.
import unittest
import os
from monty.serialization import loadfn
import warnings
import numpy as np
import multiprocessing
from pymatgen.analysis.pourbaix_diagram import PourbaixDiagram, PourbaixEntry,\
... | dongsenfo/pymatgen | pymatgen/analysis/tests/test_pourbaix_diagram.py | Python | mit | 12,311 | [
"pymatgen"
] | e8e55ed4e1567af4b635e6e27af1c5791893f417df3d114aafb4b68c35e333c0 |
#!/usr/bin/python -OO
import re
r"""
--- Day 9: All in a Single Night ---
Every year, Santa manages to deliver all of his presents in a single night.
This year, however, he has some new locations to visit; his elves have provided him the distances between every pair of locations. He can start and end at any two (diff... | hermes-jr/adventofcode-in-python | level_09/level_09.py | Python | mit | 3,815 | [
"VisIt"
] | 2c6b32cde83c68021924e95d9eac5427d3e143f38042720702e0047e0a199d03 |
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or... | googleapis/gapic-generator-python | tests/integration/goldens/credentials/tests/unit/gapic/credentials_v1/test_iam_credentials.py | Python | apache-2.0 | 82,980 | [
"Octopus"
] | e829456c2a250d226a919eab710baaa05b6662b9d9783b4f500ea790bd874741 |
#!/usr/bin/env python
'''
This file defines a Plotter actor. The plotting uses a Tkinter GUI and
runs in a seperate process.
The "actor" is composed of:
* a decorating actor *New_Process_Actor* which allows a class to run
in a separate process. It has an additional actor:
* Channel2Process which takes ... | mm318/scipysim-nogui | scipysim/actors/display/plotter.py | Python | gpl-3.0 | 11,317 | [
"Brian"
] | f41eb319ce0f6b2e1260d431dfd65ce9a547c4f9e4c571abeda4ebe1de31608b |
from basesynapse import BaseSynapse
import numpy as np
import pycuda.gpuarray as garray
from pycuda.tools import dtype_to_ctype
import pycuda.driver as cuda
from pycuda.compiler import SourceModule
cuda_src = """
__global__ void alpha_synapse(
int num,
%(type)s dt,
int *spike,
int *Pre,
%(type)s ... | AdamRTomkins/libSpineML2NK | libSpineML2NK/synapses/AlphaSynapse.py | Python | gpl-3.0 | 3,671 | [
"NEURON"
] | 9a38112a76b47ee3d8ffc2c4e638df132ff9411edaf196221ee5fdfa6d1bd2d3 |
# Copyright Iris contributors
#
# This file is part of Iris and is released under the LGPL license.
# See COPYING and COPYING.LESSER in the root of the repository for full
# licensing details.
"""
Provides objects for building up expressions useful for pattern matching.
"""
from collections.abc import Iterable, Mappi... | SciTools/iris | lib/iris/_constraints.py | Python | lgpl-3.0 | 21,207 | [
"NetCDF"
] | 3dee11b5a30f4583212d386ed8bebfba65f17ade483d242425a9d194c8afce35 |
"""User-friendly public interface to polynomial functions. """
from __future__ import print_function, division
from sympy.core import (
S, Basic, Expr, I, Integer, Add, Mul, Dummy, Tuple
)
from sympy.core.basic import preorder_traversal
from sympy.core.compatibility import iterable, range, ordered
from sympy.core... | kaushik94/sympy | sympy/polys/polytools.py | Python | bsd-3-clause | 182,487 | [
"Gaussian"
] | ccc55db8287f0c1c83e35929b55b8baabc4cf31dca20b15f3432827e285f2f57 |
# Copyright (c) 2010 Howard Hughes Medical Institute.
# All rights reserved.
# Use is subject to Janelia Farm Research Campus Software Copyright 1.1 license terms.
# http://license.janelia.org/license/jfrc_copyright_1_1.html
import neuroptikon
from os import path
from neuro_object import NeuroObject
from neurite i... | JaneliaSciComp/Neuroptikon | Source/network/neuron.py | Python | bsd-3-clause | 22,759 | [
"NEURON"
] | 2dfd678c57edcf56b44427357566c2099584c9e2814cedcd6e4a66edaec66ee1 |
# Copyright 2014-2018 The PySCF Developers. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by appl... | gkc1000/pyscf | pyscf/nao/test/test_0144_h2b_uks_pz_pb.py | Python | apache-2.0 | 1,654 | [
"PySCF"
] | ae4479de2f8504579e7181602189af6cfa791621296836b69455848e87194f87 |
from setuptools import find_packages, setup
LONG_DESCRIPTION = ''
try:
with open('./README.md', 'r') as f:
LONG_DESCRIPTION = f.read()
except FileNotFoundError:
pass
setup(
name='raspapreco',
description='Pesquisador de preços',
long_description=LONG_DESCRIPTION,
version='0.0.1',
u... | IvanBrasilico/raspa-preco | setup.py | Python | gpl-3.0 | 1,739 | [
"RASPA"
] | ae3ac3f6b6ac1737bd669ef1034e792a998515969400472087ab0621f2dffea0 |
#!/usr/bin/env python
'''
ViSAPy example script for generating benchmark corresponding to an in vivo
tetrode recording
'''
#import modules
import uuid
import urllib2
import zipfile
import numpy as np
import h5py
import os
import glob
#workaround for plots on cluster
if not os.environ.has_key('DISPLAY'):
import matp... | espenhgn/ViSAPy | examples/example_in_vivo_polytrode.py | Python | gpl-2.0 | 14,774 | [
"NEURON"
] | 3cec00b3f2f4bdea3fe47ee191dd11c6c3d8ca4e3bbba6479abf5c371e54c5bf |
""" Test for Profiler.py
"""
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function
import time
from os.path import dirname, join
from subprocess import Popen
import pytest
from flaky import flaky
import DIRAC
from DIRAC.Core.Utilities.Profiler import Profiler
... | yujikato/DIRAC | src/DIRAC/Core/Utilities/test/Test_Profiler.py | Python | gpl-3.0 | 3,974 | [
"DIRAC"
] | 43beb6ea9427317a793a76a9f51fca93ab29a1a7084fb49d0aecf657d111fe4c |
# Copyright (C) 2009, Thomas Leonard
# See the README file for details, or visit http://0install.net.
import sys
import gtk
from dialog import Template
from zeroinstall import _
from zeroinstall.gtkui import help_box
from zeroinstall.injector.model import network_levels
from zeroinstall.injector import trust, gpg
from... | rammstein/0install | zeroinstall/0launch-gui/preferences.py | Python | lgpl-2.1 | 7,731 | [
"VisIt"
] | e2868c362908c4cdad7f7d8d9cef8e83f890e89dbf08eb9b47556781990c2d2e |
# -*- coding: utf-8 -*-
#
# This file is part of INSPIRE.
# Copyright (C) 2014, 2015 CERN.
#
# INSPIRE is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any... | Dziolas/inspire-next | inspire/modules/authors/views.py | Python | gpl-2.0 | 11,226 | [
"VisIt"
] | 7fd4a0066b84163c990042491c7a73a052ce2cd4b7c8711a5f9f4750e9953bfe |
from builtins import object
from future.utils import with_metaclass
import abc
class ActionMapping(with_metaclass(abc.ABCMeta, object)):
"""
Action Mapping abc for discrete and continuous actions
"""
def __init__(self, belief_node):
self.owner = belief_node
@abc.abstractmethod
def ge... | pemami4911/POMDPy | pomdpy/pomdp/action_mapping.py | Python | mit | 3,473 | [
"VisIt"
] | e4777f5f4c148d5d35839c0dbd179e90bbdf19d08ee289d5c366963c74854e6f |
#!/usr/bin/env python
"""
Allows to add a specified extension to an already existing DIRAC installation.
The extension can come from another project than the one installed.
No new version directory is created. The command is based on the main DIRAC installer dirac-install.py.
Usage:
dirac-install-extension [options]... | yujikato/DIRAC | src/DIRAC/Core/scripts/dirac_install_extension.py | Python | gpl-3.0 | 5,929 | [
"DIRAC"
] | 59771aab9c4dfbd508243aad21360fb77ce3c93167edcfc444a95869a0f9c916 |
# Copyright (c) 2012 The Chromium Authors. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
"""Provides an interface to communicate with the device via the adb command.
Assumes adb binary is currently on system path.
"""
# pylint: skip-file
im... | CTSRD-SOAAP/chromium-42.0.2311.135 | build/android/pylib/android_commands.py | Python | bsd-3-clause | 73,018 | [
"Galaxy"
] | 26b5e96c1e86d6870b9df85c0f6d2801c875f085ee3bf9c84f18876040ab3310 |
# -*- coding: utf-8 -*-
#
# Copyright (c) 2017, the cclib development team
#
# This file is part of cclib (http://cclib.github.io) and is distributed under
# the terms of the BSD 3-Clause License.
"""Run parser unit tests for cclib."""
import sys
import unittest
sys.path.append('parser')
from testdata import *
from ... | gaursagar/cclib | test/test_parser.py | Python | bsd-3-clause | 420 | [
"cclib"
] | f8ae637c26dbaf95b9e022488bd4d11290b4d2f3e9cbd3d241bda8796b1ea9d8 |
# Gambit scripts
#
# Copyright (C) USC Information Sciences Institute
# Author: Nibir Bora <nbora@usc.edu>
# URL: <http://cbg.isi.edu/>
# For license information, see LICENSE
import os
import sys
import csv
import math
import pickle
import anyjson
import psycopg2
import matplotlib
import numpy as np
import lib.geo as ... | nbir/gambit-scripts | scripts/calc_visits/src/calc_visits.py | Python | apache-2.0 | 12,535 | [
"VisIt"
] | dabd9d8300fce087c28e0fe12a4650ad01d35dcf5d4eec086a6c84d5329d3ff1 |
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# Copyright (C) 2016 Robin Schneider <ypid@riseup.net>
# Copyright (C) 2016 DebOps <https://debops.org/>
# SPDX-License-Identifier: AGPL-3.0-only
#
# debops-api is part of DebOps.
#
# debops-api is free software: you can redistribute it and/or modify
# it under the terms o... | ganto/debops | lib/debops-api/debops/api.py | Python | gpl-3.0 | 26,388 | [
"Galaxy"
] | 18bb7acbaff9e5951b24903e83db08d515fbb7d4fb080cd4aa44a4a063632302 |
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements. See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership. The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not u... | lewismc/climate | examples/knmi_to_cru31_full_bias.py | Python | apache-2.0 | 9,616 | [
"NetCDF"
] | d8d4af7e220268e088ebd3efb3baa872bc8b68680a51baec2036af90fbb27c25 |
#!/usr/bin/env python
"""
list replicas for files in the FileCatalog
"""
import os
import DIRAC
from COMDIRAC.Interfaces import critical, error
from COMDIRAC.Interfaces import DSession
from COMDIRAC.Interfaces import DCatalog
from COMDIRAC.Interfaces import pathFromArgument
from DIRAC.Core.Utilities.ReturnValues imp... | calancha/COMDIRAC | Interfaces/scripts/dreplicas.py | Python | gpl-3.0 | 1,474 | [
"DIRAC"
] | 7fb4eb5259123d070e1ec4115cfb42222b7bc06799badd529f8996c885c819b5 |
#! /usr/bin/env python3
'''
Convert a mesh file to another.
'''
from __future__ import print_function
import numpy
import vtk
import meshio
def _main():
# Parse command line arguments.
args = _parse_options()
# read mesh data
points, cells, point_data, cell_data, field_data = \
meshio.read(a... | kayarre/Tools | vtk/read_vtu.py | Python | bsd-2-clause | 6,164 | [
"VTK"
] | dcb357962ac169a3d2eadb40a1d6a327816aafb05c3c0bef905de7aeed61e820 |
# -*- coding: utf-8 -*-
#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2000-2006 Donald N. Allingham
# Copyright (C) 2012 Doug Blank
# Copyright (C) 2013 John Ralls <jralls@ceridwen.us>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the... | ennoborg/gramps | gramps/gen/const.py | Python | gpl-2.0 | 11,397 | [
"Brian"
] | 018602b1edfd2100505cb60dbaa583df92d16d4313a218f39ab3a6895f7a25ff |
"""Berendsen NVT dynamics class."""
import sys
import numpy as np
from ase.md.md import MolecularDynamics
# For parallel GPAW simulations, the random forces should be distributed.
if '_gpaw' in sys.modules:
# http://wiki.fysik.dtu.dk/gpaw
from gpaw.mpi import world as gpaw_world
else:
gpaw_world = None
... | slabanja/ase | ase/md/nvtberendsen.py | Python | gpl-2.0 | 3,395 | [
"ASE",
"GPAW"
] | 0a39c94333889178a8c36a1e7c32e85e44325bd607485782285631564537f669 |
# Copyright (C) 2009, Thomas Leonard
# See the README file for details, or visit http://0install.net.
from __future__ import print_function
import os, sys
import logging
import warnings
import locale
from zeroinstall import localedir
if localedir:
# Tell GTK where to find the translations, if they're not in
# the... | afb/0install | zeroinstall/gui/main.py | Python | lgpl-2.1 | 6,705 | [
"VisIt"
] | 774c42108419fd9d3636b6a515f7e094a213266db5411f6120c07b6f2a68327e |
"""
============================================
client - Client Manager for the Pushover API
============================================
This module defines classes and functions necessary to act as a Client to the Pushover servers. For more details about
the Pushover API for clients visit `their site <https://push... | KronosKoderS/pypushover | pypushover/client.py | Python | mit | 11,439 | [
"VisIt"
] | 8916cb38bef4c9c9aad185cbcc5cb6429275aca8b12874599fe31860489388a9 |
from setuptools import find_packages, setup
import os
dir_path = os.path.dirname(os.path.realpath(__file__))
long_description = """
Pipelign
--------
An automated pipeline for multiple sequence alignment.
"""
setup(
name='pipelign',
version='0.1',
author='Mukarram Hossain',
author_email='asmmh2@cam.... | asmmhossain/pipelign | setup.py | Python | mit | 700 | [
"Biopython"
] | 4c08bd95e67245e353f16fbb073f380fba1480a736d75c51a9328d3ff5dbb1af |
"""
This module contains functions needed to evaluate post selection
p-values for non polyhedral selection procedures through a variety of means.
These p-values appear for the group LASSO global null test as well as the nuclear norm
p-value test.
They are described in the `Kac Rice`_ paper.
.. _Kac Rice: http://arx... | stefanv/selective-inference | selection/distributions/pvalue.py | Python | bsd-3-clause | 8,308 | [
"Gaussian"
] | d654d341faccb140f874f43619eaebf541bb637fe3564cdc6f11fe0a78f0b97a |
# -*- encoding: utf-8 -*-
"""
Gaussian optics.
The module implements:
Ray transfer matrices for geometrical and gaussian optics
See RayTransferMatrix, GeometricRay and BeamParameter
Conjugation relations for geometrical and gaussian optics
See geometric_conj*, gauss_conj and conjugate_gauss_beams
Th... | ichuang/sympy | sympy/physics/gaussopt.py | Python | bsd-3-clause | 19,249 | [
"Gaussian"
] | 9b8d191a1397a7c1f5b05ce8ba3b2e3289c960dcd5a59f7c426a6ee24325cb0a |
# The MIT License
#
# Copyright 2014, 2015 Piotr Dabkowski
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the 'Software'),
# to deal in the Software without restriction, including without limitation the rights
# to use, copy, modif... | alfa-jor/addon | plugin.video.alfa/lib/pyjsparser/parser.py | Python | gpl-3.0 | 107,162 | [
"VisIt"
] | 571df1243611750985ecadba2cfda047ff5a43f176422ecb95f946b9ceb207be |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.